# [Zope-tests] OK : Zope-2.10 Python-2.4.6 : Linux

Zope Tests zope-tests at epy.co.at
Tue Feb 1 01:04:42 EST 2011

- Previous message: [Zope-tests] OK : Zope Buildbot / zopetoolkit-py2.5 slave-ubuntu64
- Next message: [Zope-tests] OK : Zope-2.11 Python-2.4.6 : Linux
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    Zope Tests : OK
    Zope-2.10 Python-2.4.6 : Linux (x86_64)

    Running /usr/local/python2.4/bin/python test.py -q --all
    Running unit tests:
      Ran 6016 tests with 0 failures and 0 errors in 118.195 seconds.
    Running OFS.tests.testCopySupportEvents.EventLayer tests:
      Set up OFS.tests.testCopySupportEvents.EventLayer in 0.210 seconds.
      Ran 14 tests with 0 failures and 0 errors in 0.190 seconds.
    Running OFS.tests.testCopySupportHooks.HookLayer tests:
      Tear down OFS.tests.testCopySupportEvents.EventLayer in 0.002 seconds.
      Set up OFS.tests.testCopySupportHooks.HookLayer in 0.210 seconds.
      Ran 14 tests with 0 failures and 0 errors in 0.142 seconds.
    Running Testing.ZopeTestCase.zopedoctest.testLayerExtraction.TestLayer tests:
      Tear down OFS.tests.testCopySupportHooks.HookLayer in 0.002 seconds.
      Set up Testing.ZopeTestCase.zopedoctest.testLayerExtraction.TestLayer in 0.001 seconds.
      Ran 2 tests with 0 failures and 0 errors in 0.007 seconds.
    Tearing down left over layers:
      Tear down Testing.ZopeTestCase.zopedoctest.testLayerExtraction.TestLayer in 0.001 seconds.
    Total: 6046 tests, 0 failures, 0 errors

    OK

- Previous message: [Zope-tests] OK : Zope Buildbot / zopetoolkit-py2.5 slave-ubuntu64
- Next message: [Zope-tests] OK : Zope-2.11 Python-2.4.6 : Linux
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list